@@ -1,17 +1,14 @@
-from sklearn.ensemble import RandomForestClassifier
-from micromlgen.utils import jinja
+from micromlgen.utils import jinja, check_type
 
 
 def is_randomforest(clf):
     """Test if classifier can be ported"""
-    return isinstance(clf, RandomForestClassifier)
+    return check_type(clf, 'RandomForestClassifier')
 
 
-def port_randomforest(clf, classname=None, **kwargs):
+def port_randomforest(clf, **kwargs):
     """Port sklearn's RandomForestClassifier"""
-    kwargs['classname'] = kwargs['classname'] or 'RandomForest'
     return jinja('randomforest/randomforest.jinja', {
-        'classname': classname or 'RandomForestClassifier',
         'n_classes': clf.n_classes_,
         'trees': [{
             'left': clf.tree_.children_left,
@@ -20,4 +17,6 @@ def port_randomforest(clf, classname=None, **kwargs):
             'thresholds': clf.tree_.threshold,
             'classes': clf.tree_.value,
         } for clf in clf.estimators_]
-    }, **locals())
\ No newline at end of file
+    }, {
+        'classname': 'RandomForest'
+    }, **kwargs)
\ No newline at end of file
